"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const DIRECTIONS = {
  CLOCKWISE: 'clockwise',
  ANTI_CLOCKWISE: 'antiClockwise',
  BOTH_SIDES: 'bothSides'
};

const getSvgClassName = (strokePercentage, direction, className) => (0, _classnames.default)('react-circle_svg', `react-circle_${direction}`, className);

const Circle = ({
  className,
  direction,
  strokeWidth,
  strokePercentage,
  onTransitionEnd
}) => {
  const svgRef = (0, _react.useRef)(null);
  const [circleState, setCircleState] = (0, _react.useState)();
  const [svgState, setSvgState] = (0, _react.useState)({
    className: getSvgClassName(strokePercentage, direction, className)
  });
  (0, _react.useEffect)(() => {
    const {
      clientWidth: svgSize
    } = svgRef.current;
    const center = svgSize / 2;
    const radius = Math.max(center - parseInt(strokeWidth, 10), 0);
    const perimeter = 2 * Math.PI * radius;
    const rotate = -strokePercentage * 180;
    const strokeLineSize = perimeter * strokePercentage;
    const strokeGapSize = perimeter - strokeLineSize;
    const strokeDasharray = `${strokeLineSize} ${strokeGapSize}`;
    const circleStyle = {
      strokeWidth,
      strokeDasharray
    };
    const groupStyle = {};

    if (direction === DIRECTIONS.BOTH_SIDES) {
      groupStyle.transform = `rotate(${rotate}deg)`;
    }

    setCircleState({
      center,
      radius,
      perimeter,
      rotate,
      strokeGapSize,
      strokeLineSize,
      strokeDasharray,
      circleStyle,
      groupStyle
    });
    setSvgState({
      className: getSvgClassName(strokePercentage, direction, className)
    });
  }, [svgRef, strokeWidth, strokePercentage, direction, className]);
  return /*#__PURE__*/_react.default.createElement("svg", {
    ref: svgRef,
    className: svgState.className
  }, svgRef.current && /*#__PURE__*/_react.default.createElement("g", {
    style: circleState.groupStyle
  }, /*#__PURE__*/_react.default.createElement("circle", {
    style: circleState.circleStyle,
    cx: circleState.center,
    cy: circleState.center,
    r: circleState.radius,
    onTransitionEnd: onTransitionEnd
  })));
};

Circle.propTypes = {
  className: _propTypes.default.string,
  direction: _propTypes.default.oneOf(Object.values(DIRECTIONS)),
  strokeWidth: _propTypes.default.number,
  strokePercentage: _propTypes.default.number,
  onTransitionEnd: _propTypes.default.func
};
Circle.defaultProps = {
  direction: DIRECTIONS.CLOCKWISE,
  strokeWidth: 1.5,
  strokePercentage: 1
};
var _default = Circle;
exports.default = _default;
module.exports = exports.default;